@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2016
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -19,7 +19,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2    
 "splint" <- function(x, y, xgrid, wt = NULL, derivative = 0, 
-    lam = 0, df = NA, lambda = NULL) {
+    lam = 0, df = NA, lambda = NULL, nx=NULL, digits=8) {
     #
     # reform calling args if passed as a matrix or list
     
@@ -35,25 +35,46 @@
         y <- x$y
         x <- x$x
     }
+  #default values for weights
+  # NOTE: weights do not matter when interpolating (lam==0)
+  if (is.null(wt)) {
+    wt <- rep(1, length( x))
+  }
+  
+  print( x)
+  print( y)
     if (any(duplicated(x))) {
-        stop("duplicated x values, use sreg")
+      warning("Duplicate x's using the average value")
+      N<- length( x)
+      print( x)
+      print( y)
+      out <- Krig.replicates(
+        list( x=x, y=y, weights= wt, N=N, Z=NULL), 
+        verbose=TRUE
+        )
+      x<- out$xM
+      y<- out$yM
+      wt<- out$weightsM 
+      #stop("duplicated x values, use sreg")
     }
     if ((derivative > 2) | (derivative < 0)) 
         stop("derivative must be 0,1,2")
     if (length(x) != length(y)) 
         stop("Lengths of x and y must match")
     n <- length(x)
-    #default values for weights
-    # NOTE: weights do not matter when interpolating (lam==0)
-    if (is.null(wt)) {
-        wt <- rep(1, n)
-    }
+    if( n > 5e4){
+        stop("splint not dimensioned for more than 50000 observations")
+        }
+    
     # find lambda from eff degrees of freedom if it is passed
     if (!is.na(df)) {
         if ((df < 2) | (df > n)) {
             stop("df out of range")
         }
+      print( x)
+      print(wt)
         lam <- sreg.df.to.lambda(df, x, wt)
+        print( lam)
     }
     # use lambda is it is passed
     if (!is.null(lambda)) {
@@ -61,8 +82,11 @@
     }
     igcv <- ifelse(lam == 0, 2, 0)
     # call to FORTRAN -- only return the evaluated poiints (ygrid).
-    return(
-           .Fortran("css",PACKAGE="fields",
+    if( !is.null(nx)){
+      xgrid<- seq( min( x), max(x),,nx)
+    }
+  
+           ygrid<- .Fortran("css",PACKAGE="fields",
                      h = as.double(ifelse(igcv == 2, 1, log(lam))),
                      as.integer(n),
                      as.double(x),
@@ -79,5 +103,10 @@
                      as.integer(derivative), 
                      as.integer(0)
                      )$ygrid
- )
+ if(!is.null(nx) ){ 
+   return(list( x=xgrid, y=ygrid))
+}
+else{ 
+  return( ygrid)
+  }
 }
